You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@skywalking.apache.org by wu...@apache.org on 2021/06/28 07:39:19 UTC

[skywalking-goapi] 11/16: Add miss grpc entity (#7)

This is an automated email from the ASF dual-hosted git repository.

wusheng pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/skywalking-goapi.git

commit d6b3f6c1724087d532252e257b0818995c2c5600
Author: mrproliu <74...@qq.com>
AuthorDate: Sat Jun 5 21:55:04 2021 +0800

    Add miss grpc entity (#7)
    
    Co-authored-by: Mrproliu <mr...@lagou.com>
---
 satellite/data/v1/SniffData.pb.go | 142 ++++++++++++++++++++++++++++----------
 satellite/data/v1/SniffData.proto |   3 +
 2 files changed, 107 insertions(+), 38 deletions(-)

diff --git a/satellite/data/v1/SniffData.proto b/satellite/data/v1/SniffData.proto
index 02f0146..ebd0089 100644
--- a/satellite/data/v1/SniffData.proto
+++ b/satellite/data/v1/SniffData.proto
@@ -70,5 +70,8 @@ message SniffData {
     ThreadSnapshot profile = 12;
     ServiceMeshMetric serviceMesh = 13;
     Event event = 14;
+    InstancePingPkg instancePing = 15;
+    ProfileTaskCommandQuery profileTaskQuery = 16;
+    ProfileTaskFinishReport profileTaskFinish = 17;
   }
 }
diff --git a/satellite/data/v1/SniffData.pb.go b/satellite/data/v1/SniffData.pb.go
index b007152..64a411b 100644
--- a/satellite/data/v1/SniffData.pb.go
+++ b/satellite/data/v1/SniffData.pb.go
@@ -139,6 +139,9 @@ type SniffData struct {
 	//	*SniffData_Profile
 	//	*SniffData_ServiceMesh
 	//	*SniffData_Event
+	//	*SniffData_InstancePing
+	//	*SniffData_ProfileTaskQuery
+	//	*SniffData_ProfileTaskFinish
 	Data isSniffData_Data `protobuf_oneof:"data"`
 }
 
@@ -279,6 +282,27 @@ func (x *SniffData) GetEvent() *v35.Event {
 	return nil
 }
 
+func (x *SniffData) GetInstancePing() *v32.InstancePingPkg {
+	if x, ok := x.GetData().(*SniffData_InstancePing); ok {
+		return x.InstancePing
+	}
+	return nil
+}
+
+func (x *SniffData) GetProfileTaskQuery() *v33.ProfileTaskCommandQuery {
+	if x, ok := x.GetData().(*SniffData_ProfileTaskQuery); ok {
+		return x.ProfileTaskQuery
+	}
+	return nil
+}
+
+func (x *SniffData) GetProfileTaskFinish() *v33.ProfileTaskFinishReport {
+	if x, ok := x.GetData().(*SniffData_ProfileTaskFinish); ok {
+		return x.ProfileTaskFinish
+	}
+	return nil
+}
+
 type isSniffData_Data interface {
 	isSniffData_Data()
 }
@@ -319,6 +343,18 @@ type SniffData_Event struct {
 	Event *v35.Event `protobuf:"bytes,14,opt,name=event,proto3,oneof"`
 }
 
+type SniffData_InstancePing struct {
+	InstancePing *v32.InstancePingPkg `protobuf:"bytes,15,opt,name=instancePing,proto3,oneof"`
+}
+
+type SniffData_ProfileTaskQuery struct {
+	ProfileTaskQuery *v33.ProfileTaskCommandQuery `protobuf:"bytes,16,opt,name=profileTaskQuery,proto3,oneof"`
+}
+
+type SniffData_ProfileTaskFinish struct {
+	ProfileTaskFinish *v33.ProfileTaskFinishReport `protobuf:"bytes,17,opt,name=profileTaskFinish,proto3,oneof"`
+}
+
 func (*SniffData_Clr) isSniffData_Data() {}
 
 func (*SniffData_Jvm) isSniffData_Data() {}
@@ -337,6 +373,12 @@ func (*SniffData_ServiceMesh) isSniffData_Data() {}
 
 func (*SniffData_Event) isSniffData_Data() {}
 
+func (*SniffData_InstancePing) isSniffData_Data() {}
+
+func (*SniffData_ProfileTaskQuery) isSniffData_Data() {}
+
+func (*SniffData_ProfileTaskFinish) isSniffData_Data() {}
+
 var File_satellite_SniffData_proto protoreflect.FileDescriptor
 
 var file_satellite_SniffData_proto_rawDesc = []byte{
@@ -358,7 +400,7 @@ var file_satellite_SniffData_proto_rawDesc = []byte{
 	0x25, 0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x2d, 0x6d, 0x65, 0x73, 0x68, 0x2d, 0x70, 0x72,
 	0x6f, 0x62, 0x65, 0x2f, 0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x2d, 0x6d, 0x65, 0x73, 0x68,
 	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x11, 0x65, 0x76, 0x65, 0x6e, 0x74, 0x2f, 0x45, 0x76,
-	0x65, 0x6e, 0x74, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xf4, 0x05, 0x0a, 0x09, 0x53, 0x6e,
+	0x65, 0x6e, 0x74, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xe8, 0x07, 0x0a, 0x09, 0x53, 0x6e,
 	0x69, 0x66, 0x66, 0x44, 0x61, 0x74, 0x61, 0x12, 0x1c, 0x0a, 0x09, 0x74, 0x69, 0x6d, 0x65, 0x73,
 	0x74, 0x61, 0x6d, 0x70, 0x18, 0x01, 0x20, 0x01, 0x28, 0x03, 0x52, 0x09, 0x74, 0x69, 0x6d, 0x65,
 	0x73, 0x74, 0x61, 0x6d, 0x70, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x02, 0x20,
@@ -401,26 +443,41 @@ var file_satellite_SniffData_proto_rawDesc = []byte{
 	0x69, 0x63, 0x48, 0x00, 0x52, 0x0b, 0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x4d, 0x65, 0x73,
 	0x68, 0x12, 0x2c, 0x0a, 0x05, 0x65, 0x76, 0x65, 0x6e, 0x74, 0x18, 0x0e, 0x20, 0x01, 0x28, 0x0b,
 	0x32, 0x14, 0x2e, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69, 0x6e, 0x67, 0x2e, 0x76, 0x33,
-	0x2e, 0x45, 0x76, 0x65, 0x6e, 0x74, 0x48, 0x00, 0x52, 0x05, 0x65, 0x76, 0x65, 0x6e, 0x74, 0x1a,
-	0x37, 0x0a, 0x09, 0x4d, 0x65, 0x74, 0x61, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03,
-	0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x14,
-	0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x52, 0x05, 0x76,
-	0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x42, 0x06, 0x0a, 0x04, 0x64, 0x61, 0x74, 0x61,
-	0x2a, 0xa7, 0x01, 0x0a, 0x09, 0x53, 0x6e, 0x69, 0x66, 0x66, 0x54, 0x79, 0x70, 0x65, 0x12, 0x11,
-	0x0a, 0x0d, 0x43, 0x4c, 0x52, 0x4d, 0x65, 0x74, 0x72, 0x69, 0x63, 0x54, 0x79, 0x70, 0x65, 0x10,
-	0x00, 0x12, 0x11, 0x0a, 0x0d, 0x4a, 0x56, 0x4d, 0x4d, 0x65, 0x74, 0x72, 0x69, 0x63, 0x54, 0x79,
-	0x70, 0x65, 0x10, 0x01, 0x12, 0x0d, 0x0a, 0x09, 0x4d, 0x65, 0x74, 0x65, 0x72, 0x54, 0x79, 0x70,
-	0x65, 0x10, 0x02, 0x12, 0x0f, 0x0a, 0x0b, 0x54, 0x72, 0x61, 0x63, 0x69, 0x6e, 0x67, 0x54, 0x79,
-	0x70, 0x65, 0x10, 0x03, 0x12, 0x0b, 0x0a, 0x07, 0x4c, 0x6f, 0x67, 0x67, 0x69, 0x6e, 0x67, 0x10,
-	0x04, 0x12, 0x12, 0x0a, 0x0e, 0x4d, 0x61, 0x6e, 0x61, 0x67, 0x65, 0x6d, 0x65, 0x6e, 0x74, 0x54,
-	0x79, 0x70, 0x65, 0x10, 0x05, 0x12, 0x0f, 0x0a, 0x0b, 0x50, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65,
-	0x54, 0x79, 0x70, 0x65, 0x10, 0x06, 0x12, 0x13, 0x0a, 0x0f, 0x53, 0x65, 0x72, 0x76, 0x69, 0x63,
-	0x65, 0x4d, 0x65, 0x73, 0x68, 0x54, 0x79, 0x70, 0x65, 0x10, 0x07, 0x12, 0x0d, 0x0a, 0x09, 0x45,
-	0x76, 0x65, 0x6e, 0x74, 0x54, 0x79, 0x70, 0x65, 0x10, 0x08, 0x42, 0x34, 0x5a, 0x32, 0x73, 0x6b,
-	0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69, 0x6e, 0x67, 0x2e, 0x61, 0x70, 0x61, 0x63, 0x68, 0x65, 0x2e,
-	0x6f, 0x72, 0x67, 0x2f, 0x72, 0x65, 0x70, 0x6f, 0x2f, 0x67, 0x6f, 0x61, 0x70, 0x69, 0x2f, 0x73,
-	0x61, 0x74, 0x65, 0x6c, 0x6c, 0x69, 0x74, 0x65, 0x2f, 0x64, 0x61, 0x74, 0x61, 0x2f, 0x76, 0x31,
-	0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
+	0x2e, 0x45, 0x76, 0x65, 0x6e, 0x74, 0x48, 0x00, 0x52, 0x05, 0x65, 0x76, 0x65, 0x6e, 0x74, 0x12,
+	0x44, 0x0a, 0x0c, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x50, 0x69, 0x6e, 0x67, 0x18,
+	0x0f, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1e, 0x2e, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69,
+	0x6e, 0x67, 0x2e, 0x76, 0x33, 0x2e, 0x49, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x50, 0x69,
+	0x6e, 0x67, 0x50, 0x6b, 0x67, 0x48, 0x00, 0x52, 0x0c, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63,
+	0x65, 0x50, 0x69, 0x6e, 0x67, 0x12, 0x54, 0x0a, 0x10, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65,
+	0x54, 0x61, 0x73, 0x6b, 0x51, 0x75, 0x65, 0x72, 0x79, 0x18, 0x10, 0x20, 0x01, 0x28, 0x0b, 0x32,
+	0x26, 0x2e, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69, 0x6e, 0x67, 0x2e, 0x76, 0x33, 0x2e,
+	0x50, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x54, 0x61, 0x73, 0x6b, 0x43, 0x6f, 0x6d, 0x6d, 0x61,
+	0x6e, 0x64, 0x51, 0x75, 0x65, 0x72, 0x79, 0x48, 0x00, 0x52, 0x10, 0x70, 0x72, 0x6f, 0x66, 0x69,
+	0x6c, 0x65, 0x54, 0x61, 0x73, 0x6b, 0x51, 0x75, 0x65, 0x72, 0x79, 0x12, 0x56, 0x0a, 0x11, 0x70,
+	0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x54, 0x61, 0x73, 0x6b, 0x46, 0x69, 0x6e, 0x69, 0x73, 0x68,
+	0x18, 0x11, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x26, 0x2e, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b,
+	0x69, 0x6e, 0x67, 0x2e, 0x76, 0x33, 0x2e, 0x50, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x54, 0x61,
+	0x73, 0x6b, 0x46, 0x69, 0x6e, 0x69, 0x73, 0x68, 0x52, 0x65, 0x70, 0x6f, 0x72, 0x74, 0x48, 0x00,
+	0x52, 0x11, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x54, 0x61, 0x73, 0x6b, 0x46, 0x69, 0x6e,
+	0x69, 0x73, 0x68, 0x1a, 0x37, 0x0a, 0x09, 0x4d, 0x65, 0x74, 0x61, 0x45, 0x6e, 0x74, 0x72, 0x79,
+	0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03, 0x6b,
+	0x65, 0x79, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28,
+	0x09, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x42, 0x06, 0x0a, 0x04,
+	0x64, 0x61, 0x74, 0x61, 0x2a, 0xa7, 0x01, 0x0a, 0x09, 0x53, 0x6e, 0x69, 0x66, 0x66, 0x54, 0x79,
+	0x70, 0x65, 0x12, 0x11, 0x0a, 0x0d, 0x43, 0x4c, 0x52, 0x4d, 0x65, 0x74, 0x72, 0x69, 0x63, 0x54,
+	0x79, 0x70, 0x65, 0x10, 0x00, 0x12, 0x11, 0x0a, 0x0d, 0x4a, 0x56, 0x4d, 0x4d, 0x65, 0x74, 0x72,
+	0x69, 0x63, 0x54, 0x79, 0x70, 0x65, 0x10, 0x01, 0x12, 0x0d, 0x0a, 0x09, 0x4d, 0x65, 0x74, 0x65,
+	0x72, 0x54, 0x79, 0x70, 0x65, 0x10, 0x02, 0x12, 0x0f, 0x0a, 0x0b, 0x54, 0x72, 0x61, 0x63, 0x69,
+	0x6e, 0x67, 0x54, 0x79, 0x70, 0x65, 0x10, 0x03, 0x12, 0x0b, 0x0a, 0x07, 0x4c, 0x6f, 0x67, 0x67,
+	0x69, 0x6e, 0x67, 0x10, 0x04, 0x12, 0x12, 0x0a, 0x0e, 0x4d, 0x61, 0x6e, 0x61, 0x67, 0x65, 0x6d,
+	0x65, 0x6e, 0x74, 0x54, 0x79, 0x70, 0x65, 0x10, 0x05, 0x12, 0x0f, 0x0a, 0x0b, 0x50, 0x72, 0x6f,
+	0x66, 0x69, 0x6c, 0x65, 0x54, 0x79, 0x70, 0x65, 0x10, 0x06, 0x12, 0x13, 0x0a, 0x0f, 0x53, 0x65,
+	0x72, 0x76, 0x69, 0x63, 0x65, 0x4d, 0x65, 0x73, 0x68, 0x54, 0x79, 0x70, 0x65, 0x10, 0x07, 0x12,
+	0x0d, 0x0a, 0x09, 0x45, 0x76, 0x65, 0x6e, 0x74, 0x54, 0x79, 0x70, 0x65, 0x10, 0x08, 0x42, 0x34,
+	0x5a, 0x32, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69, 0x6e, 0x67, 0x2e, 0x61, 0x70, 0x61,
+	0x63, 0x68, 0x65, 0x2e, 0x6f, 0x72, 0x67, 0x2f, 0x72, 0x65, 0x70, 0x6f, 0x2f, 0x67, 0x6f, 0x61,
+	0x70, 0x69, 0x2f, 0x73, 0x61, 0x74, 0x65, 0x6c, 0x6c, 0x69, 0x74, 0x65, 0x2f, 0x64, 0x61, 0x74,
+	0x61, 0x2f, 0x76, 0x31, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
 }
 
 var (
@@ -438,18 +495,21 @@ func file_satellite_SniffData_proto_rawDescGZIP() []byte {
 var file_satellite_SniffData_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
 var file_satellite_SniffData_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
 var file_satellite_SniffData_proto_goTypes = []interface{}{
-	(SniffType)(0),                 // 0: skywalking.v3.SniffType
-	(*SniffData)(nil),              // 1: skywalking.v3.SniffData
-	nil,                            // 2: skywalking.v3.SniffData.MetaEntry
-	(*v3.CLRMetricCollection)(nil), // 3: skywalking.v3.CLRMetricCollection
-	(*v3.JVMMetricCollection)(nil), // 4: skywalking.v3.JVMMetricCollection
-	(*v3.MeterData)(nil),           // 5: skywalking.v3.MeterData
-	(*v3.SegmentObject)(nil),       // 6: skywalking.v3.SegmentObject
-	(*v31.LogData)(nil),            // 7: skywalking.v3.LogData
-	(*v32.InstanceProperties)(nil), // 8: skywalking.v3.InstanceProperties
-	(*v33.ThreadSnapshot)(nil),     // 9: skywalking.v3.ThreadSnapshot
-	(*v34.ServiceMeshMetric)(nil),  // 10: skywalking.v3.ServiceMeshMetric
-	(*v35.Event)(nil),              // 11: skywalking.v3.Event
+	(SniffType)(0),                      // 0: skywalking.v3.SniffType
+	(*SniffData)(nil),                   // 1: skywalking.v3.SniffData
+	nil,                                 // 2: skywalking.v3.SniffData.MetaEntry
+	(*v3.CLRMetricCollection)(nil),      // 3: skywalking.v3.CLRMetricCollection
+	(*v3.JVMMetricCollection)(nil),      // 4: skywalking.v3.JVMMetricCollection
+	(*v3.MeterData)(nil),                // 5: skywalking.v3.MeterData
+	(*v3.SegmentObject)(nil),            // 6: skywalking.v3.SegmentObject
+	(*v31.LogData)(nil),                 // 7: skywalking.v3.LogData
+	(*v32.InstanceProperties)(nil),      // 8: skywalking.v3.InstanceProperties
+	(*v33.ThreadSnapshot)(nil),          // 9: skywalking.v3.ThreadSnapshot
+	(*v34.ServiceMeshMetric)(nil),       // 10: skywalking.v3.ServiceMeshMetric
+	(*v35.Event)(nil),                   // 11: skywalking.v3.Event
+	(*v32.InstancePingPkg)(nil),         // 12: skywalking.v3.InstancePingPkg
+	(*v33.ProfileTaskCommandQuery)(nil), // 13: skywalking.v3.ProfileTaskCommandQuery
+	(*v33.ProfileTaskFinishReport)(nil), // 14: skywalking.v3.ProfileTaskFinishReport
 }
 var file_satellite_SniffData_proto_depIdxs = []int32{
 	0,  // 0: skywalking.v3.SniffData.type:type_name -> skywalking.v3.SniffType
@@ -463,11 +523,14 @@ var file_satellite_SniffData_proto_depIdxs = []int32{
 	9,  // 8: skywalking.v3.SniffData.profile:type_name -> skywalking.v3.ThreadSnapshot
 	10, // 9: skywalking.v3.SniffData.serviceMesh:type_name -> skywalking.v3.ServiceMeshMetric
 	11, // 10: skywalking.v3.SniffData.event:type_name -> skywalking.v3.Event
-	11, // [11:11] is the sub-list for method output_type
-	11, // [11:11] is the sub-list for method input_type
-	11, // [11:11] is the sub-list for extension type_name
-	11, // [11:11] is the sub-list for extension extendee
-	0,  // [0:11] is the sub-list for field type_name
+	12, // 11: skywalking.v3.SniffData.instancePing:type_name -> skywalking.v3.InstancePingPkg
+	13, // 12: skywalking.v3.SniffData.profileTaskQuery:type_name -> skywalking.v3.ProfileTaskCommandQuery
+	14, // 13: skywalking.v3.SniffData.profileTaskFinish:type_name -> skywalking.v3.ProfileTaskFinishReport
+	14, // [14:14] is the sub-list for method output_type
+	14, // [14:14] is the sub-list for method input_type
+	14, // [14:14] is the sub-list for extension type_name
+	14, // [14:14] is the sub-list for extension extendee
+	0,  // [0:14] is the sub-list for field type_name
 }
 
 func init() { file_satellite_SniffData_proto_init() }
@@ -499,6 +562,9 @@ func file_satellite_SniffData_proto_init() {
 		(*SniffData_Profile)(nil),
 		(*SniffData_ServiceMesh)(nil),
 		(*SniffData_Event)(nil),
+		(*SniffData_InstancePing)(nil),
+		(*SniffData_ProfileTaskQuery)(nil),
+		(*SniffData_ProfileTaskFinish)(nil),
 	}
 	type x struct{}
 	out := protoimpl.TypeBuilder{